'use strict';

/* @flow */

import braintree from 'braintree-web';


export function BraintreeWrapper(token:string):Object {

    const BTW = {};

    BTW.client = new braintree.api.Client({
        clientToken: token
    });

    /**
     *
     * Example Billing Address:
     * {
     *               firstName: $("#first_name").val(),
     *               lastName: $("#last_name").val(),
     *               company: $("#company").val(),
     *               streetAddress: $("#street_address").val(),
     *               extendedAddress: $("#extended_address").val(),
     *               locality: $("#locality").val(),
     *               region: $("#region").val(),
     *               postalCode: $("#postal_code").val(),
     *               countryName: $("#country_name").val()
     *           }
     * @param formResult
     */

    BTW.createSepaMandate = function createSepaMandate(formResult:Object):Promise {
        return new Promise((resolve, reject) => {
            this.client.createSEPAMandate(formResult,
                function (err, result) {

                    console.log('Error:', err);
                    console.log('Result:', result);

                    if (err) {
                        return reject(err);
                    }

                    let m = result.sepaMandate;
                    resolve({
                        mandateReferenceNumber: m.mandateReferenceNumber,
                        shortForm: m.shortForm,
                        longForm: m.longFormURL,
                        nonce: result.sepaBankAccount.nonce
                    });
                });
        });
    };

    /**
     *
     * Example form result:
     *
     * {
     *           number: "4111111111111111",
     *           cardholderName: "John Smith",
     *           // You can use either expirationDate
     *           expirationDate: "10/20",
     *           // or expirationMonth and expirationYear
     *           expirationMonth: "10",
     *           expirationYear: "2015",
     *           // CVV if required
     *           cvv: "832",
     *           // Address if AVS is on
     *           billingAddress: {
     *               postalCode: "94107"
     *           }
     *       }
     * @param formResult
     * @returns {Promise|Promise<T>}
     */

    BTW.tokenizeCard = function tokenizeCard(formResult:Object):Promise {
        return new Promise((resolve, reject) => {
            this.client.tokenizeCard(formResult,
                (err, nonce) => {

                    console.log('Error:', err);
                    console.log('Result:', nonce);


                    if (err) {
                        return reject(err);
                    }
                    resolve(nonce);
                });
        });
    };


    return BTW;
}
